import { useEffect, useRef, useState } from 'react';
import { TinyArea, TinyColumn } from '@ant-design/charts';
import { Card, Col, Progress, Row, Tabs, DatePicker, Select, Form, Statistic, Button } from 'antd';
import numeral from 'numeral';
import { ChartCard, Field } from './Charts';
import type { DataItem } from '../data.d';

import { getAsyncOrgTree, getEduUnitList } from '../service';
const { Option } = Select;

import styles from '../style.less';
import ProForm, { ProFormSelect } from '@ant-design/pro-form';
import { useRequest } from 'umi';
const { RangePicker } = DatePicker;
const topColResponsiveProps = {
  xs: 24,
  sm: 4,
  md: 4,
  lg: 4,
  xl: 4,
  offset: 1,
  style: { marginBottom: 24 },
};

const layout = {
  labelCol: { span: 8 },
  wrapperCol: { span: 16 },
};




const IntroduceRow = ({ loading, visitData }: { loading: boolean; visitData: DataItem[] }) => {
  const [provinceId, setProvinceId] = useState("100007")
  const [cityList, setCityList] = useState([]);
  const [areaList, setAreaList] = useState([]);

  const [schoolList, setSchoolList] = useState([]);

  const { loading: courseBrowseTimesLoading, data: eduUnitList = null } = useRequest(() => getEduUnitList({
    random_num: 277470,
    area_id: provinceId,
    edu_type: -1,
    // main_school_id: 200125116,
    // org_name:"",
    org_type: 2,
    pageNumber: 1,
    pageSize: 1000,
    school_type: -1,
    showPassWord: true,
  }), {
    formatResult: (result) => {
      return result.table_List;
    }
  });







  const [form] = Form.useForm();

  // eslint-disable-next-line react-hooks/exhaustive-deps
  useEffect(async () => {
    const cityData = await getAsyncOrgTree({
      org_id: provinceId,
      org_type: 1,
      get_next: 1
    });
    setCityList(cityData || []);






  }, []);


  const getAreaData = async (e) => {
    // console.log(e, 'eeeeeeeeeeeee2ee');
    const areaData = await getAsyncOrgTree({
      org_id: e,
      org_type: 2,
      get_next: 1
    });
    form.setFieldsValue({ area: 0 })
    setAreaList(areaData || []);



  }
  let timeout: NodeJS.Timeout | null;

  const getSchoolData = async (e, callback) => {

    // timeout = setTimeout(async () => {
    try {
      schoolData = await getEduUnitList({
        random_num: 277470,
        area_id: provinceId,
        edu_type: -1,
        // main_school_id: 200125116,
        org_name: e,
        org_type: 2,
        pageNumber: 1,
        pageSize: 1000,
        school_type: -1,
        showPassWord: true,
      }).then((e) => {
        callback(e.table_List)
        console.log(e.table_List);
        setSchoolList(e.table_List || [])

      });
    } catch (error) {
      // error.message; // "Oops!"
    }

    // }, 500);

    // console.log(schoolList, 'schoolList 1');


  }


  const onFinish = (values: any) => {
    console.log(values);
  };

  const onGenderChange = (value: string) => {

    // const options = this.state.data.map(d => <Option key={d.value}>{d.text}</Option>);


  };
  return (
    <Card loading={loading} bordered={false} bodyStyle={{ padding: 0, marginBottom: '24px' }}>
      <div className={styles.salesCard}>
        <Tabs
          tabBarExtraContent={<div className={styles.salesExtraWrap}>
            <div className={styles.salesExtra}>


              <Form {...layout} form={form} name="control-hooks" onFinish={onFinish}>

                <Form.Item name="city" label="市" style={{ float: "left" }}>


                  <Select
                    style={{ width: 120 }}
                    onChange={(id) => { getAreaData(id) }}
                  // defaultValue={provinceId}
                  >
                    <Option key={provinceId} value={provinceId}>全部</Option>
                    {/* {cityList.map((e, i) => {

                      return <Option key={e.id} value={e.id}>{e.name}</Option>
                    })} */}
                  </Select>
                </Form.Item>

                <Form.Item name="area" label="区" style={{ float: "left" }}>


                  <Select
                    style={{ width: 120 }}
                    // defaultValue={0}
                    onChange={(id) => { getSchoolData(id) }}
                  >
                    <Option key={0} value={0}>全部</Option>
                    {/* {areaList.map((e, i) => {

                      return <Option key={e.id} value={e.id}>{e.name}</Option>
                    })} */}
                  </Select>

                </Form.Item>

                <Form.Item name="school" label="学校">


                  <Select
                    showSearch
                    style={{ width: 220 }}
                    // value={this.state.value}
                    // placeholder={this.props.placeholder}
                    // style={this.props.style}
                    // defaultActiveFirstOption={true}
                    showArrow={true}
                    filterOption={true}
                    // onSearch={this.handleSearch}
                    // onChange={getSchoolData}
                    fieldNames={{ value: "ORG_ID", label: "ORG_NAME" }}
                    onSearch={(value) => getSchoolData(value)}
                    notFoundContent={null}
                    options={schoolList}


                  />
                  {console.log(schoolList, 'schoolList111')}
                </Form.Item>

                <Button>确定</Button>
              </Form>
            </div>

          </div>

          }
          size="large"
          tabBarStyle={{ marginBottom: 24 }}
        />
      </div>
      <Row />
      <Row gutter={16}>
        <Col  {...topColResponsiveProps}>
          <Statistic title="资质考试数" value={93} />
        </Col>
        <Col  {...topColResponsiveProps}>
          <Statistic title="累计报名人数" value={93} suffix="人" />
        </Col>
        <Col  {...topColResponsiveProps}>
          <Statistic title="取得证书人数" value={93} suffix="人" />
        </Col>
        <Col {...topColResponsiveProps}>
          <ChartCard
            bordered={false}
            loading={loading}
            title={`通过率`}
            action={false}
            // total={`${numeral(6560).format('0,0')}`}
            footer={false}
            contentHeight={92}
            style={{ textAlign: 'center', marginBottom: 0 }}
          >
            <Progress type="circle" percent={75} width={80} strokeWidth={10} style={{ position: 'relative', margin: '15px auto 0 auto' }} />
          </ChartCard>
        </Col>
      </Row>
    </Card >)


};

export default IntroduceRow;
