import { AlignLeftOutlined, LaptopOutlined, NotificationOutlined, PlusOutlined, UserOutlined } from '@ant-design/icons';
import { Button, Card, Col, Layout, List, Menu, Progress, Row, Typography } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { useRequest } from 'umi';
import { queryFakeList } from './service';
import type { CardListItemDataType } from './data';
import styles from './style.less';
import { Content } from 'antd/lib/layout/layout';
import Sider from 'antd/lib/layout/Sider';
import SubMenu from 'antd/lib/menu/SubMenu';
import { VideoJS } from '../components/VideoJS';
import { useRef } from 'react';

const { Paragraph } = Typography;

const CardList = () => {
  const videoRef = useRef<HTMLVideoElement>(null);
  const { data, loading } = useRequest(() => {
    return queryFakeList({
      count: 8,
    });
  });

  const list = data?.list || [];

  const content = (
    <div className={styles.pageHeaderContent}>
      <Card
        title={<a>{'生涯规划师初级认证培训课程你收到了 14 份新周报'}</a>}
        hoverable={false}
        className={styles.card}
        actions={[]}
        extra={<><span style={{padding:10}}>开始学习时间: 2020-4-9</span><span style={{padding:10}}>距离结束时间：300天</span><span style={{padding:10}}>考核学时：36学时</span></>}
      >
        <Card.Meta          
          avatar={<img alt="" className={styles.cardAvatar} src={'https://gw.alipayobjects.com/zos/rmsportal/uMfMFlvUuceEyPpotzlq.png'} style={{width:'270px', height:'150px', borderRadius:'10px'}} />}
          title={false}
          description={
            <>
              <Card.Grid hoverable={false} style={{width:'100%',padding:0, boxShadow:'none'}}>
                <Paragraph className={styles.item} ellipsis={{ rows: 4 }} style={{paddingLeft:10}}>
                  {'请大家在规定时间内完成本培训任务安排，逾期本培训任务将自动关闭。祝大家学习愉快！请大家在规定时间内完成本培训任务安排，逾期本培训任务将自动关闭。祝大家学习愉快！这种模板用于提醒谁与你发生了互动，左侧放『谁』的头像'}
                </Paragraph>
                <Row>
                  <Col span={16} style={{display:'inline-block', padding:10}}><span>学习进度：</span><span style={{display:'inline-block', width:'80%'}}><Progress percent={75} /></span></Col>
                </Row>
                <Row>                  
                  <Col span={10} style={{padding:10}}><span>上次学习：</span><span>生涯规划之升学路径知多少</span></Col> <Col span={10} style={{padding:10}}>主讲人：<span>盖笑松</span></Col> <Col span={4} style={{padding:10}}><Button type="primary">去学习</Button></Col>
                </Row>
              </Card.Grid>
            </>                      
          }
        />
      </Card>
    </div>
  );

  //const videoInfo = {url:'http://cctvalih5ca.v.myalicdn.com/live/cctv1_2/index.m3u8', img:''}
  //const videoInfo = {url:'https://media.w3.org/2010/05/sintel/trailer_hd.mp4', img:''}
  const videoInfo = {url:'http://10.10.14.199/dsideal_yy/html/down/M3u8/2D/2D99BF1D-2F37-47FB-8A24-45112A236B8F.m3u8', img:''}
  
  const nullData: Partial<CardListItemDataType> = {};
  return (
    <PageContainer content={content} extraContent={false}>
      <Row>
        <Col span={6} style={{paddingRight:24}}>
          <Menu
            mode="inline"
            defaultSelectedKeys={['1']}
            defaultOpenKeys={['sub1']}
            style={{ height: '100%', width:'100%' }}
          >
            <SubMenu key="sub1" icon={<AlignLeftOutlined />} title="章节目录">
              <Menu.Item key="1">第1节 特质因素理论</Menu.Item>
              <Menu.Item key="2">第2节 生涯发展理论</Menu.Item>
              <Menu.Item key="3">第3节 明尼苏达工作适应论</Menu.Item>
            </SubMenu>       
          </Menu>
        </Col>
        <Col span={18} style={{background:'#ffffff', padding:24}}>
          {
                videoInfo.url && <VideoJS options={{
                  controls: true,
                     playbackRates: [0.7, 1.0, 1.5, 2.0], // 播放速度
                     autoplay: false, // 如果true,浏览器准备好时开始回放。
                     muted: false, // 默认情况下将会消除任何音频。
                     loop: true, // 导致视频一结束就重新开始。
                     preload: 'auto', // 建议浏览器在<video>加载元素后是否应该开始下载视频数据。auto浏览器选择最佳行为,立即开始加载视频（如果浏览器支持）
                     language: 'zh-CN',
                     aspectRatio: '16:9', // 将播放器置于流畅模式，并在计算播放器的动态大小时使用该值。值应该代表一个比例 - 用冒号分隔的两个数字（例如"16:9"或"4:3"）
                     fluid: true, // 当true时，Video.js player将拥有流体大小。换句话说，它将按比例缩放以适应其容器。
                     sources: [
                       {
                         src: videoInfo.url,
                         type: 'application/x-mpegURL'
                       }
                     ],
                     poster: videoInfo.img, // 你的封面地址
                     width: document.documentElement.clientWidth,
                     notSupportedMessage: '此视频暂无法播放，请稍后再试', // 允许覆盖Video.js无法播放媒体源时显示的默认信息。
                     controlBar: {
                       timeDivider: true,
                       durationDisplay: true,
                       remainingTimeDisplay: true,
                       fullscreenToggle: true // 全屏按钮
                     }
                  
                  
                }} onReady={(play: any)=>{
                  console.log('play====',play);
                  videoRef.current = play
                  play.play()
                }}/>
              }
        </Col>
      </Row>

    </PageContainer>
  );
};

export default CardList;
