import { AlignLeftOutlined, LaptopOutlined, NotificationOutlined, PlusOutlined, UserOutlined } from '@ant-design/icons';
import { Button, Card, Col, Layout, List, Menu, Progress, Row, Typography } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { useRequest } from 'umi';
import { queryFakeList } from './service';
import type { CardListItemDataType } from './data.d';
import styles from './style.less';
import { Content } from 'antd/lib/layout/layout';
import Sider from 'antd/lib/layout/Sider';
import SubMenu from 'antd/lib/menu/SubMenu';
console.log('course/list')
const { Paragraph } = Typography;

const CardList = () => {
  const { data, loading } = useRequest(() => {
    return queryFakeList({
      count: 8,
    });
  });

  const list = data?.list || [];

  const content = (
    <div className={styles.pageHeaderContent}>
      <Card
        title={<a>{'生涯规划师初级认证培训课程你收到了 14 份新周报'}</a>}
        hoverable={false}
        className={styles.card}
        actions={[]}
        extra={<><span style={{padding:10}}>开始学习时间: 2020-4-9</span><span style={{padding:10}}>距离结束时间：300天</span><span style={{padding:10}}>考核学时：36学时</span></>}
      >
        <Card.Meta          
          avatar={<img alt="" className={styles.cardAvatar} src={'https://gw.alipayobjects.com/zos/rmsportal/uMfMFlvUuceEyPpotzlq.png'} style={{width:'270px', height:'150px', borderRadius:'10px'}} />}
          title={false}
          description={
            <>
              <Card.Grid hoverable={false} style={{width:'100%',padding:0, boxShadow:'none'}}>
                <Paragraph className={styles.item} ellipsis={{ rows: 4 }} style={{paddingLeft:10}}>
                  {'请大家在规定时间内完成本培训任务安排，逾期本培训任务将自动关闭。祝大家学习愉快！请大家在规定时间内完成本培训任务安排，逾期本培训任务将自动关闭。祝大家学习愉快！这种模板用于提醒谁与你发生了互动，左侧放『谁』的头像'}
                </Paragraph>
                <Row>
                  <Col span={16} style={{display:'inline-block', padding:10}}><span>学习进度：</span><span style={{display:'inline-block', width:'80%'}}><Progress percent={75} /></span></Col>
                </Row>
                <Row>                  
                  <Col span={10} style={{padding:10}}><span>上次学习：</span><span>生涯规划之升学路径知多少</span></Col> <Col span={10} style={{padding:10}}>主讲人：<span>盖笑松</span></Col> <Col span={4} style={{padding:10}}><Button type="primary">去学习</Button></Col>
                </Row>
              </Card.Grid>
            </>                      
          }
        />
      </Card>
    </div>
  );


  const nullData: Partial<CardListItemDataType> = {};
  return (
    <PageContainer content={content} extraContent={false}>
      <Row>
        <Col span={6} style={{paddingRight:24}}>
          <Menu
            mode="inline"
            defaultSelectedKeys={['1']}
            defaultOpenKeys={['sub1']}
            style={{ height: '100%', width:'100%' }}
          >
            <SubMenu key="sub1" icon={<AlignLeftOutlined />} title="章节目录">
              <Menu.Item key="1">生涯规划理论</Menu.Item>
              <Menu.Item key="2">生涯规划基本步骤</Menu.Item>
              <Menu.Item key="3">生涯测评的应用与实践</Menu.Item>
              <Menu.Item key="4">生涯测评的应用与实践</Menu.Item>
              <Menu.Item key="5">生涯测评的应用与实践</Menu.Item>
              <Menu.Item key="6">生涯测评的应用与实践</Menu.Item>
              <Menu.Item key="7">生涯测评的应用与实践</Menu.Item>
              <Menu.Item key="8">生涯测评的应用与实践</Menu.Item>

              <Menu.Item key="9">生涯测评的应用与实践</Menu.Item>
              <Menu.Item key="10">生涯测评的应用与实践</Menu.Item>
              <Menu.Item key="11">生涯测评的应用与实践</Menu.Item>
              <Menu.Item key="12">生涯测评的应用与实践</Menu.Item>
            </SubMenu>       
          </Menu>
        </Col>
        <Col span={18} style={{background:'#ffffff', padding:24}}>
          <List<Partial<CardListItemDataType>>
          rowKey="id"
          loading={loading}
          grid={{
            gutter: 1,
            xs: 1,
            sm: 2,
            md: 1,
            lg: 1,
            xl: 1,
            xxl: 1,
          }}
          dataSource={[nullData, ...list]}
          renderItem={(item) => {
            if (item && item.id) {
              return (
                <List.Item key={item.id}>
                  <Card
                    hoverable={false}
                    className={styles.card}
                    actions={[]}
                    style={{background:'#f0f0f0'}}
                  >
                    <Card.Meta
                      avatar={false}
                      title={<a>{item.title}</a>}
                      description={
                        <Row>
                          <Col span={4} style={{padding:10}}>
                            第1讲
                          </Col>
                          <Col span={8} style={{padding:10}}>
                            <Paragraph className={styles.item} ellipsis={{ rows: 3 }}>
                              {item.description}
                            </Paragraph>
                          </Col>
                          <Col span={4} style={{padding:10, textAlign:'center'}}>
                            23分钟
                          </Col>
                          <Col span={4} style={{padding:10, textAlign:'center'}}>
                            <Progress percent={30} />
                          </Col>
                          <Col span={4} style={{padding:10, textAlign:'center'}}>
                            <Button type="primary">学习</Button>
                          </Col>
                        </Row>
                      }
                    />
                  </Card>
                </List.Item>
              );
            }            
          }}
        />
        </Col>
      </Row>

    </PageContainer>
  );
};

export default CardList;
