import type { FC } from 'react';
import { Suspense } from 'react';
import { Avatar, Card, Col, List, Skeleton, Row, Statistic, Descriptions, Progress, Table, Button } from 'antd';
import { Line, Radar } from '@ant-design/charts';
import { Link, history, useRequest } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import moment from 'moment';
import EditableLinkGroup from './components/EditableLinkGroup';
import styles from './style.less';
import type { ActivitiesType, CurrentUser } from './data.d';
import { personLastLearning, queryActivities, fakeChartData } from './service';
import cookie from 'react-cookies';
import OfflineData from './components/OfflineData';


const examinations = [
  {
    key: '1',
    name: '生涯规划师初级认证培训1',
    appyTime: '2021/12/25-2021/12/26',
    examTime: '2021/12/27',
    status: 0
  },
  {
    key: '2',
    name: '生涯规划师初级认证培训2',
    appyTime: '2021/12/25-2021/12/26',
    examTime: '2021/12/27',
    status: -1
  },
  {
    key: '3',
    name: '生涯规划师初级认证培训3',
    appyTime: '2021/12/25-2021/12/26',
    examTime: '2021/12/27',
    status: 0
  },
  {
    key: '4',
    name: '生涯规划师初级认证培训4',
    appyTime: '2021/12/25-2021/12/26',
    examTime: '2021/12/27',
    status: 0
  },
  {
    key: '5',
    name: '生涯规划师初级认证培训5',
    appyTime: '2021/12/25-2021/12/26',
    examTime: '2021/12/27',
    status: 0
  },
];

/** 考试字段 */
const examinationColumns = [
  {
    title: '考试项目',
    dataIndex: 'name',
    key: 'name',
  },
  {
    title: '报名时间',
    dataIndex: 'appyTime',
    key: 'appyTime',
  },
  {
    title: '考试时间',
    dataIndex: 'examTime',
    key: 'examTime',
  },
  {
    title: '',
    dataIndex: 'option',
    key: 'option',
    render: (_, record, index, action) => {
      return record?.status === 0 ? <Button type="primary" onClick={() => { history.push('/registration') }} style={{ minWidth: 88 }}>去报名</Button> : <Button type="primary" onClick={() => { history.push('/examination/paper') }} style={{ minWidth: 88 }}>参加考试</Button>
    },
  },
];

/** 证书字段 */
const certificateColumns = [
  {
    title: '考试项目',
    dataIndex: 'name',
    key: 'name',
  },
  {
    title: '考试时间',
    dataIndex: 'examTime',
    key: 'examTime',
  },
  {
    title: '通过情况',
    dataIndex: 'statusExam',
    key: 'statusExam',
  },
  {
    title: '证书情况',
    dataIndex: 'statusCertificate',
    key: 'statusCertificate',
  },
];

const certificates = [
  {
    key: '1',
    name: '生涯规划师初级认证',
    examTime: '2021/12/27',
    statusExam: 'ok',
    statusCertificate: 'yes'
  },
  {
    key: '2',
    name: '生涯规划师初级认证2',
    examTime: '2021/12/27',
    statusExam: 'ok',
    statusCertificate: 'yes'
  },
  {
    key: '3',
    name: '生涯规划师初级认证3',
    examTime: '2021/12/27',
    statusExam: 'ok',
    statusCertificate: 'yes'
  },
  {
    key: '4',
    name: '生涯规划师初级认证4',
    examTime: '2021/12/27',
    statusExam: 'ok',
    statusCertificate: 'yes'
  },
  {
    key: '5',
    name: '生涯规划师初级认证5',
    examTime: '2021/12/27',
    statusExam: 'ok',
    statusCertificate: 'yes'
  },
];

const Workplace: FC = () => {
  // const { loading: lastLearningLoading, data: lastLearningList = [] } = useRequest(
  //   personLastLearning(
  //     {
  //       identity_id: cookie.load('identity_id'),
  //       person_id: cookie.load('person_id')
  //     }));
  const { loading: activitiesLoading, data: activities = [] } = useRequest(queryActivities);
  const { loading: offlineChartLoading, data: offlineChartData = [] } = useRequest(fakeChartData);

  const { data } = useRequest(fakeChartData); // 证书
  console.log('lastLearningList', lastLearningList)
  return (
    <>
      <Row gutter={24}>
        <Col xl={12} lg={12} md={12} sm={12} xs={12}>
          <Card
            className={styles.projectList}
            style={{ marginBottom: 24 }}
            title="学习概况"
            bordered={false}
            extra={false}
            loading={offlineChartLoading}
            bodyStyle={{ padding: 24 }}
          >
            <div className={styles.extraContent}>
              <div className={styles.statItem}>
                <Statistic title="今日学习" value={56} suffix=" 分钟" />
              </div>
              <div className={styles.statItem}>
                <Statistic title="累计登录天数" value={8} suffix=" 天" />
              </div>
            </div>
            <div style={{ width: '100%', padding: 24 }}>
              <Line
                color={'#1859ff'}
                forceFit
                height={400}
                data={[{ date: '2022/10/20', value: 50 }, { date: '2022/10/21', value: 300 }, { date: '2022/10/22', value: 480 }, { date: '2022/10/23', value: 210 }, { date: '2022/10/24', value: 250 }, { date: '2022/10/25', value: 240 }]}
                //responsive
                xField="date"
                yField="value"
                //seriesField="type"  
                legend={{
                  position: 'top-center',
                }}
                point={{ size: 5 }}
              />
            </div>
          </Card>
          <Card
            bodyStyle={{ padding: 15 }}
            bordered={false}
            className={styles.studyCard}
            title="当前学习"
            loading={activitiesLoading}
            cover={<img alt="example" src="https://os.alipayobjects.com/rmsportal/QBnOOoLaAfKPirc.png" />}
          >
            <Descriptions title="生涯规划之升学路径知多少" layout='horizontal' column={1} >
              <Descriptions.Item label="主将人">盖笑松</Descriptions.Item>
              <Descriptions.Item label="章节">生涯决策</Descriptions.Item>
              <Descriptions.Item label="主题">1234123421</Descriptions.Item>
              <Descriptions.Item label="时长">40分钟</Descriptions.Item>
            </Descriptions>
            <Progress percent={30} />
          </Card>
        </Col>
        <Col xl={12} lg={12} md={12} sm={12} xs={12}>
          <Card
            style={{ marginBottom: 24 }}
            title="资质考试"
            bordered={false}
            bodyStyle={{ padding: 0 }}
          >
            <div className={styles.chart}><Table dataSource={examinations} columns={examinationColumns} pagination={false} /></div>

          </Card>
          <Card
            style={{ marginBottom: 24 }}
            bordered={false}
            title="证书查询"
            loading={data?.radarData?.length === 0}
          >
            <div className={styles.chart}>
              <Table dataSource={certificates} columns={certificateColumns} pagination={false} />
            </div>
          </Card>
        </Col>
      </Row>
    </>
  );
};

export default Workplace;
