import React, { useRef } from 'react';
import { history } from 'umi';
import { ProFormInstance, ProFormRadio } from '@ant-design/pro-form';
import ProForm, {
  StepsForm,
  ProFormText,
  ProFormDatePicker,
  ProFormSelect,
  ProFormTextArea,
  ProFormCheckbox,
  ProFormDateRangePicker,
} from '@ant-design/pro-form';
import ProCard from '@ant-design/pro-card';
import { Button, Col, message, Row } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import ProDescriptions from '@ant-design/pro-descriptions';

const waitTime = (time: number = 100) => {
  return new Promise((resolve) => {
    setTimeout(() => {
      resolve(true);
    }, time);
  });
};

export default () => {
  const formRef = useRef<ProFormInstance>();

  return (
    <PageContainer content={''} extraContent={''}>
        <ProCard>
        <StepsForm<{
            name: string;
        }>
            formRef={formRef}
            onFinish={async () => {
            await waitTime(1000);
            message.success('提交成功');
            }}
            formProps={{
                layout: "horizontal",
                labelCol: { span: 8 },
                wrapperCol: { span: 12 },
                validateMessages: {
                    required: '此项为必填项',
                },
            }}
        >
            <StepsForm.StepForm<{
                name: string;
            }>
                name="base"
                title="填写基本信息"
                stepProps={{
                    description: false,
                }}
                onFinish={async () => {
                    console.log(formRef.current?.getFieldsValue());
                    await waitTime(2000);
                    return true;
                }}
            >
                <Row gutter={24}>
                    <Col lg={12} md={12} sm={24}>
                        <ProFormText
                            name="name"
                            label="考生姓名"
                            width="md"
                            // tooltip="最长为 6 位汉字，需要与考生身份证一致"
                            placeholder="请输入姓名"
                            // rules={[{ required: true }]}
                            value="锦书"
                            disabled
                        />
                        <ProFormText name="idcard" label="身份证" />
                        <ProFormDatePicker name="birthday" label="出生年月" />
                        <ProFormRadio.Group
                            options={[
                            {
                                value: '1',
                                label: '男',
                            },
                            {
                                value: '2',
                                label: '女',
                            },
                            ]}
                            label="性别"
                            name="sex"
                        />                
                        <ProFormText name="address" label="家庭地址" />
                        <ProFormText name="contact" label="联系方式" width="lg" placeholder="联系方式" />                        
                    </Col>
                    <Col lg={12} md={12} sm={24}>
                    <ProFormText name="org" label="所在学校" width="lg" placeholder="请填写" value='昆明市第一中学' disabled />
                        <ProFormSelect
                            label='最高学历'
                            name="owner"
                            rules={[{ required: true, message: '请选择最高学历' }]}
                            options={[
                            {
                                label: '研究生',
                                value: '3',
                            },
                            {
                                label: '本科',
                                value: '2',
                            },
                            {
                                label: '专科',
                                value: '1',
                            },
                            ]}
                            placeholder="请选择"
                        />
                        <ProFormText name="address" label="毕业学校" />
                        <ProFormText name="address" label="专业" />
                        <ProFormSelect
                            label='任教学科'
                            name="owner"
                            rules={[{ required: true, message: '请选择最高学历' }]}
                            options={[
                            {
                                label: '语文',
                                value: '3',
                            },
                            {
                                label: '数学',
                                value: '2',
                            },
                            {
                                label: '英语',
                                value: '1',
                            },
                            ]}
                            placeholder="请选择"
                        />
                    </Col>
                </Row>
            
            </StepsForm.StepForm>

            <StepsForm.StepForm<{
                checkbox: string;
                }>
                name="object"
                title="确认考试项目"
                stepProps={{
                    description: false,
                }}
                onFinish={async () => {
                    console.log(formRef.current?.getFieldsValue());
                    return true;
                }}
            >
                <ProDescriptions
                    layout='horizontal'
                    column={1}
                    //actionRef={actionRef}
                    title="高级定义列表 request"
                    request={async () => {
                        return Promise.resolve({
                        success: true,
                        data: { id: '这是一段文本', object:'', date: '2020-07-30 08:00', duration:'', grade:100, through:'>60', learn: '>20 min', times: 2 },
                        });
                    }}
                    extra={false}
                    >
                    <ProDescriptions.Item dataIndex="id" hideInDescriptions />
                    <ProDescriptions.Item dataIndex="object" label="考试项目" valueType="text" />
                    <ProDescriptions.Item dataIndex="date" label="考试时间" valueType="text" />
                    <ProDescriptions.Item dataIndex="duration" label="考试时长" valueType="text" />
                    <ProDescriptions.Item dataIndex="grade" label="满分" valueType="text" />
                    <ProDescriptions.Item dataIndex="through" label="通过标准" valueType="text" />
                    <ProDescriptions.Item dataIndex="learn" label="报名要求" valueType="text" />
                    <ProDescriptions.Item dataIndex="times" label="考试次数" valueType="text" />                
                </ProDescriptions>
            </StepsForm.StepForm>

            <StepsForm.StepForm
                name="time"
                title="完成"
                stepProps={{
                    description: false,
                }}
                onFinish={async () => {
                    console.log(formRef.current?.getFieldsValue());
                    // 跳转到指定路由
                    history.push('/registration/success');
                    return true;
                }}
            >
                
                <Row gutter={24}>
                    <Col lg={12} md={12} sm={24}>
                        <ProDescriptions
                            layout='horizontal'
                            column={1}
                            //actionRef={actionRef}
                            title="高级定义列表 request"
                            request={async () => {
                                return Promise.resolve({
                                success: true,
                                data: { id: '这是一段文本', object:'', date: '2020-07-30 08:00', duration:'', grade:100, through:'>60', learn: '>20 min', times: 2 },
                                });
                            }}
                            extra={false}
                            >
                            <ProDescriptions.Item dataIndex="id" hideInDescriptions />
                            <ProDescriptions.Item dataIndex="object" label="考试项目" valueType="text" />
                            <ProDescriptions.Item dataIndex="date" label="考试时间" valueType="text" />
                            <ProDescriptions.Item dataIndex="duration" label="考试时长" valueType="text" />
                            <ProDescriptions.Item dataIndex="grade" label="满分" valueType="text" />
                            <ProDescriptions.Item dataIndex="through" label="通过标准" valueType="text" />
                            <ProDescriptions.Item dataIndex="learn" label="报名要求" valueType="text" />
                            <ProDescriptions.Item dataIndex="times" label="考试次数" valueType="text" />                
                        </ProDescriptions>                        
                    </Col>
                    <Col lg={12} md={12} sm={24}>
                        <ProDescriptions
                            layout='horizontal'
                            column={1}
                            //actionRef={actionRef}
                            title="高级定义列表 request"
                            request={async () => {
                                return Promise.resolve({
                                success: true,
                                data: { id: '这是一段文本', object:'', date: '2020-07-30 08:00', duration:'', grade:100, through:'>60', learn: '>20 min', times: 2 },
                                });
                                
                            }}
                            extra={false}
                            >
                            <ProDescriptions.Item dataIndex="id" hideInDescriptions />
                            <ProDescriptions.Item dataIndex="object" label="考试项目" valueType="text" />
                            <ProDescriptions.Item dataIndex="date" label="考试时间" valueType="text" />
                            <ProDescriptions.Item dataIndex="duration" label="考试时长" valueType="text" />
                            <ProDescriptions.Item dataIndex="grade" label="满分" valueType="text" />
                            <ProDescriptions.Item dataIndex="through" label="通过标准" valueType="text" />
                            <ProDescriptions.Item dataIndex="learn" label="报名要求" valueType="text" />
                            <ProDescriptions.Item dataIndex="times" label="考试次数" valueType="text" />                
                        </ProDescriptions>
                    </Col>
                </Row>
            </StepsForm.StepForm>
        </StepsForm>
        </ProCard>
    </PageContainer>

  );
};